# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Empire**, the allocation and nomination platform of BritNed_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/britned/empire-platform-api) 

    The version of the OpenAPI document: 6.0.2
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from empire_platform_api_public_client_legacy.api.bidding_configuration_api import BiddingConfigurationApi  # noqa: E501


class TestBiddingConfigurationApi(unittest.TestCase):
    """BiddingConfigurationApi unit test stubs"""

    def setUp(self) -> None:
        self.api = BiddingConfigurationApi()

    def tearDown(self) -> None:
        self.api.api_client.close()

    def test_get_bidding_configuration(self) -> None:
        """Test case for get_bidding_configuration

        """
        pass

    def test_update_bidding_configuration(self) -> None:
        """Test case for update_bidding_configuration

        """
        pass


if __name__ == '__main__':
    unittest.main()
