# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Empire**, the allocation and nomination platform of BritNed_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/britned/empire-platform-api) 

    The version of the OpenAPI document: 6.0.2
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from empire_platform_api_public_client_legacy.api.participant_dashboard_api import ParticipantDashboardApi  # noqa: E501


class TestParticipantDashboardApi(unittest.TestCase):
    """ParticipantDashboardApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ParticipantDashboardApi()

    def tearDown(self) -> None:
        self.api.api_client.close()

    def test_get_participant_dashboard_default_bids_and_nominations(self) -> None:
        """Test case for get_participant_dashboard_default_bids_and_nominations

        """
        pass

    def test_get_participant_dashboard_finance_overview(self) -> None:
        """Test case for get_participant_dashboard_finance_overview

        """
        pass

    def test_get_participant_dashboard_interconnector_capacity(self) -> None:
        """Test case for get_participant_dashboard_interconnector_capacity

        """
        pass

    def test_get_participant_dashboard_interconnector_capacity_graph(self) -> None:
        """Test case for get_participant_dashboard_interconnector_capacity_graph

        """
        pass

    def test_get_participant_dashboard_messages(self) -> None:
        """Test case for get_participant_dashboard_messages

        """
        pass

    def test_get_participant_dashboard_netted_nominations(self) -> None:
        """Test case for get_participant_dashboard_netted_nominations

        """
        pass

    def test_get_participant_dashboard_next_auctions_and_nomination_gates(self) -> None:
        """Test case for get_participant_dashboard_next_auctions_and_nomination_gates

        """
        pass

    def test_get_participant_dashboard_transmission_rights_and_nominations(self) -> None:
        """Test case for get_participant_dashboard_transmission_rights_and_nominations

        """
        pass

    def test_get_participant_dashboard_transmission_rights_and_nominations_graph(self) -> None:
        """Test case for get_participant_dashboard_transmission_rights_and_nominations_graph

        """
        pass

    def test_get_participant_dashboard_upcoming_long_term_auctions(self) -> None:
        """Test case for get_participant_dashboard_upcoming_long_term_auctions

        """
        pass


if __name__ == '__main__':
    unittest.main()
