# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Empire**, the allocation and nomination platform of BritNed_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/britned/empire-platform-api) 

    The version of the OpenAPI document: 6.0.2
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from empire_platform_api_public_client_legacy.models.day_ahead_or_intra_day_auction_results_mtu import DayAheadOrIntraDayAuctionResultsMtu  # noqa: E501

class TestDayAheadOrIntraDayAuctionResultsMtu(unittest.TestCase):
    """DayAheadOrIntraDayAuctionResultsMtu unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> DayAheadOrIntraDayAuctionResultsMtu:
        """Test DayAheadOrIntraDayAuctionResultsMtu
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `DayAheadOrIntraDayAuctionResultsMtu`
        """
        model = DayAheadOrIntraDayAuctionResultsMtu()  # noqa: E501
        if include_optional:
            return DayAheadOrIntraDayAuctionResultsMtu(
                mtu = '2022-01-04T10:00:00.000Z',
                requested_capacity = 56,
                allocated_trs = 56,
                marginal_price = 1.337,
                participant_count = 0,
                successful_participant_count = 0,
                bid_count = 0
            )
        else:
            return DayAheadOrIntraDayAuctionResultsMtu(
                mtu = '2022-01-04T10:00:00.000Z',
                requested_capacity = 56,
                allocated_trs = 56,
                marginal_price = 1.337,
                participant_count = 0,
                successful_participant_count = 0,
                bid_count = 0,
        )
        """

    def testDayAheadOrIntraDayAuctionResultsMtu(self):
        """Test DayAheadOrIntraDayAuctionResultsMtu"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
