# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Empire**, the allocation and nomination platform of BritNed_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/britned/empire-platform-api) 

    The version of the OpenAPI document: 6.0.2
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import json
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class VatRateType(str, Enum):
    """
    VatRateType
    """

    """
    allowed enum values
    """
    GB_SALES_VAT = 'GB_SALES_VAT'
    GB_VAT = 'GB_VAT'
    GB_SALES_SERVICES_OUTSIDE_EU = 'GB_SALES_SERVICES_OUTSIDE_EU'
    GB_SALES_SERVICES_WITHIN_EU = 'GB_SALES_SERVICES_WITHIN_EU'
    NL_SALES_VAT = 'NL_SALES_VAT'
    NL_SALES_VAT_ZERO = 'NL_SALES_VAT_ZERO'
    NL_SALES_SERVICES_OUTSIDE_EU = 'NL_SALES_SERVICES_OUTSIDE_EU'
    NL_SALES_SERVICES_WITHIN_EU = 'NL_SALES_SERVICES_WITHIN_EU'

    @classmethod
    def from_json(cls, json_str: str) -> VatRateType:
        """Create an instance of VatRateType from a JSON string"""
        return VatRateType(json.loads(json_str))


